@@ -12,12 +12,12 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False):
         try:
             qualname = eval(f'x.{method}.__qualname__')
             qualname = qualname.split('.')
-            passed['x'][qualname[0]].add(qualname[1])
-            passed_['x'][type_].add(qualname[1])
+            passed[f'{arg}'][qualname[0]].add(qualname[1])
+            passed_[f'{arg}'][type_].add(qualname[1])
 
         except:
-            failed['x'].add(method)
-            failed_['x'][type_].add(method)
+            failed[f'{arg}'].add(method)
+            failed_[f'{arg}'][type_].add(method)
 
     if checks:
         checks_ = {}
